@@ -214,6 +214,18 @@ where
         return self.raw.length;
     }
 
+    #[inline(always)]
+    pub unsafe fn set_len(&mut self, new_len: usize) {
+        debug_assert!(
+            new_len < self.raw.capacity,
+            "set_len got value that was too large! capa={}, new_len={}",
+            self.raw.capacity,
+            new_len
+        );
+
+        self.raw.length = new_len;
+    }
+
     #[inline(always)]
     pub fn reserve(&mut self, additional: usize) {
         self.raw.reserve_additional(&self.allocator, additional);
@@ -382,6 +394,26 @@ where
     }
 }
 
+impl<T> FromIterator<T> for Pod<T>
+where
+    T: Copy,
+{
+    fn from_iter<I>(i: I) -> Self
+    where
+        I: IntoIterator<Item = T>,
+    {
+        let iter = i.into_iter();
+
+        let mut pod = Self::with_capacity(iter.size_hint().0);
+
+        for item in iter {
+            pod.push(item);
+        }
+
+        return pod;
+    }
+}
+
 impl<T, A> Drop for Pod<T, A>
 where
     T: Copy,
